@@ -5,11 +5,11 @@
  * @date     Mon Jul 28, 2003 23:58
  * @brief    XMMS GNOME applet main file
  *
- * $Id: gxmms.c,v 1.1 2003/10/30 21:52:35 aleix Exp $
+ * $Id: gxmms.c,v 1.2 2004/09/02 22:19:54 aleix Exp $
  *
  * @if copyright
  *
- * Copyright (C) 2003 Aleix Conchillo Flaque
+ * Copyright (C) 2003, 2004 Aleix Conchillo Flaque
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -38,7 +38,7 @@
 
 PANEL_APPLET_BONOBO_FACTORY ("OAFIID:GNOME_gxmmsApplet_Factory",
                              PANEL_TYPE_APPLET,
-                             "gXMMS Applet",
+                             "gxmms applet",
                              "0",
                              gxmms_applet_factory,
                              NULL);
