@@ -5,7 +5,7 @@
  * @date     Thu Aug 07, 2003 21:16
  * @brief    XMMS GNOME applet control functions
  *
- * $Id: xmmsctrl.c,v 1.2 2004/06/09 23:40:56 aleix Exp $
+ * $Id: xmmsctrl.c,v 1.3 2004/09/02 22:19:54 aleix Exp $
  *
  * @if copyright
  *
@@ -160,6 +160,26 @@ xmms_seek(XMMSData *xmms, gdouble t)
     gui_update(xmms);
 }
 
+void
+xmms_repeat(XMMSData *xmms, gboolean active)
+{
+    if (xmms_remote_is_running(xmms->session)
+        && (xmms_remote_is_repeat(xmms->session) != active))
+    {
+        xmms_remote_toggle_repeat(xmms->session);
+    }
+}
+
+void
+xmms_shuffle(XMMSData *xmms, gboolean active)
+{
+    if (xmms_remote_is_running(xmms->session)
+        && (xmms_remote_is_shuffle(xmms->session) != active))
+    {
+        xmms_remote_toggle_shuffle(xmms->session);
+    }
+}
+
 void
 xmms_main_win(XMMSData *xmms)
 {
@@ -207,6 +227,15 @@ xmms_show_hide(XMMSData *xmms)
     }
 }
 
+void
+xmms_preferences(XMMSData *xmms)
+{
+    if (xmms_remote_is_running(xmms->session))
+    {
+        xmms_remote_show_prefs_box(xmms->session);
+    }
+}
+
 void
 xmms_lower_volume(XMMSData *xmms)
 {
