@@ -5,11 +5,11 @@
  * @date     Thu Aug 07, 2003 21:20
  * @brief    XMMS GNOME applet control functions
  *
- * $Id: xmmsctrl.h,v 1.2 2004/06/09 23:40:56 aleix Exp $
+ * $Id: xmmsctrl.h,v 1.3 2004/09/02 22:19:54 aleix Exp $
  *
  * @if copyright
  *
- * Copyright (C) 2003 Aleix Conchillo Flaque
+ * Copyright (C) 2003, 2004 Aleix Conchillo Flaque
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -49,6 +49,10 @@ void xmms_eject(XMMSData *xmms);
 
 void xmms_seek(XMMSData *xmms, gdouble t);
 
+void xmms_repeat(XMMSData *xmms, gboolean active);
+
+void xmms_shuffle(XMMSData *xmms, gboolean active);
+
 void xmms_main_win(XMMSData *xmms);
 
 void xmms_pl_win(XMMSData *xmms);
@@ -57,6 +61,8 @@ void xmms_eq_win(XMMSData *xmms);
 
 void xmms_show_hide(XMMSData *xmms);
 
+void xmms_preferences(XMMSData *xmms);
+
 void xmms_lower_volume(XMMSData *xmms);
 
 void xmms_raise_volume(XMMSData *xmms);
